
-- The Practical SQL Handbook
-- ...example DB tables, converted to PostgreSQL
--
-- $Id: bookbiz.pgres.sql,v 1.1.1.1 2001/04/12 19:20:26 biggers Exp $
--
-- \d myTable to "print" a table definition
--

CREATE TABLE authors (
    au_id char(11) not null,
    au_lname varchar(40) not null,
    au_fname varchar(20) not null,
    phone char(12),
    address varchar(40),
    city varchar(20),
    state char(2),
    zip char(5)
);

CREATE TABLE publishers (
    pub_id char(4) not null,
    pub_name varchar(40),
    address varchar(40),
    city varchar(20),
    state char(2)
);

CREATE TABLE roysched (
    title_id char(6) not null,
    lorange int,
    hirange int,
    royalty float
);

CREATE TABLE titleauthors (
    au_id char(11) not null,
    title_id char(6) not null,
    au_ord smallint,
    royaltyshare float
);

-- ! contract

CREATE TABLE titles (
    title_id char(6) not null,
    title varchar(80) not null,
    type char(12),
    pub_id char(4),
    price money,
    advance money,
    ytd_sales int,
    contract boolean not null,
    notes varchar(200),
    pubdate date
);

CREATE TABLE editors (
    ed_id char(11) not null,
    ed_lname varchar(40) not null,
    ed_fname varchar(20) not null,
    ed_pos varchar(12),
    phone char(12),
    address varchar(40),
    city varchar(20),
    state char(2),
    zip char(5)
);

-- ed_ord !

CREATE TABLE titleditors (
    ed_id char(11) not null,
    title_id char(6) not null,
    ed_ord smallint
);

CREATE TABLE sales (
    sonum int not null,
    stor_id char(4) not null,
    ponum varchar(20) not null,
    sdate date
);

CREATE TABLE salesdetails (
    sonum int not null,
    qty_ordered smallint not null,
    qty_shipped smallint,
    title_id char(6) not null,
    date_shipped date
);

CREATE UNIQUE INDEX pubind
ON publishers (pub_id);

CREATE UNIQUE INDEX auidind 
ON authors (au_id);

CREATE INDEX aunmind 
ON authors (au_lname, au_fname);

CREATE UNIQUE INDEX titleidind 
ON titles (title_id);

CREATE INDEX titleind 
ON titles (title);

CREATE UNIQUE INDEX taind 
ON titleauthors (au_id, title_id);

CREATE UNIQUE INDEX edind 
ON editors (ed_id);

CREATE INDEX ednmind 
ON editors (ed_lname, ed_fname);

CREATE UNIQUE INDEX teind 
ON titleditors (ed_id, title_id);

CREATE INDEX rstidind 
ON roysched (title_id);

INSERT INTO authors VALUES (
    '409-56-7008', 'Bennet', 'Abraham',
    '415 658-9932', '6223 Bateman St.', 'Berkeley', 'CA', '94705');

INSERT INTO authors VALUES  
    ('213-46-8915', 'Green', 'Marjorie',
    '415 986-7020', '309 63rd St. #411', 'Oakland', 'CA', '94618');

INSERT INTO authors VALUES (
    '238-95-7766', 'Carson', 'Cheryl',
    '415 548-7723', '589 Darwin Ln.', 'Berkeley', 'CA', '94705');

INSERT INTO authors VALUES (
    '998-72-3567', 'Ringer', 'Albert',
    '801 826-0752', '67 Seventh Av.', 'Salt Lake City', 'UT', '84152');

INSERT INTO authors VALUES (
    '899-46-2035', 'Ringer', 'Anne',
    '801 826-0752', '67 Seventh Av.', 'Salt Lake City', 'UT', '84152');

INSERT INTO authors VALUES (
    '722-51-5454', 'DeFrance', 'Michel',
    '219 547-9982', '3 Balding Pl.', 'Gary', 'IN', '46403');

INSERT INTO authors VALUES (
    '807-91-6654', 'Panteley', 'Sylvia',
    '301 946-8853', '1956 Arlington Pl.', 'Rockville', 'MD', '20853');

INSERT INTO authors VALUES (
    '893-72-1158', 'McBadden', 'Heather',
    '707 448-4982', '301 Putnam', 'Vacaville', 'CA', '95688');

INSERT INTO authors VALUES (
    '724-08-9931', 'Stringer', 'Dirk',
    '415 843-2991', '5420 Telegraph Av.', 'Oakland', 'CA', '94609');

INSERT INTO authors VALUES (
    '274-80-9391', 'Straight', 'Dick',
    '415 834-2919', '5420 College Av.', 'Oakland', 'CA', '94609');

INSERT INTO authors VALUES (
    '756-30-7391', 'Karsen', 'Livia',
    '415 534-9219', '5720 McAuley St.', 'Oakland', 'CA', '94609');

INSERT INTO authors VALUES (
    '724-80-9391', 'MacFeather', 'Stearns',
    '415 354-7128', '44 Upland Hts.', 'Oakland', 'CA', '94612');

INSERT INTO authors VALUES (
    '427-17-2319', 'Dull', 'Ann',
    '415 836-7128', '3410 Blonde St.', 'Palo Alto', 'CA', '94301');

INSERT INTO authors VALUES (
    '672-71-3249', 'Yokomoto', 'Akiko',
    '415 935-4228', '3 Silver Ct.', 'Walnut Creek', 'CA', '94595');

INSERT INTO authors VALUES (
    '267-41-2394', 'O''Leary', 'Michael',
    '408 286-2428', '22 Cleveland Av. #14', 'San Jose', 'CA', '95128');

INSERT INTO authors VALUES (
    '472-27-2349', 'Gringlesby', 'Burt',
    '707 938-6445', 'PO Box 792', 'Covelo', 'CA', '95428');

INSERT INTO authors VALUES (
    '527-72-3246', 'Greene', 'Morningstar',
    '615 297-2723', '22 Graybar House Rd.', 'Nashville', 'TN', '37215');

INSERT INTO authors VALUES (
    '172-32-1176', 'White', 'Johnson',
    '408 496-7223', '10932 Bigge Rd.', 'Menlo Park', 'CA', '94025');

INSERT INTO authors VALUES (
    '712-45-1867', 'del Castillo', 'Innes',
    '615 996-8275', '2286 Cram Pl. #86', 'Ann Arbor', 'MI', '48105');

INSERT INTO authors VALUES (
    '846-92-7186', 'Hunter', 'Sheryl',
    '415 836-7128', '3410 Blonde St.', 'Palo Alto', 'CA', '94301');

INSERT INTO authors VALUES (
    '486-29-1786', 'Locksley', 'Chastity',
    '415 585-4620', '18 Broadway Av.', 'San Francisco', 'CA', '94130');

INSERT INTO authors VALUES (
    '648-92-1872', 'Blotchet-Halls', 'Reginald',
    '503 745-6402', '55 Hillsdale Bl.', 'Corvallis', 'OR', '97330');

INSERT INTO authors VALUES (
    '341-22-1782', 'Smith', 'Meander',
    '913 843-0462', '10 Misisipi Dr.', 'Lawrence', 'KS', '66044');


INSERT INTO publishers VALUES (
    '0736', 'New Age Books', '1 1st St','Boston', 'MA');

INSERT INTO publishers VALUES (
    '0877', 'Binnet & Hardley','2 2nd Ave.', 'Washington', 'DC');

INSERT INTO publishers VALUES (
    '1389', 'Algodata Infosystems', '3 3rd Dr.','Berkeley', 'CA');


INSERT INTO roysched VALUES (
    'BU1032', 0, 5000, .10);

INSERT INTO roysched VALUES (
    'BU1032', 5001, 50000, .12);

INSERT INTO roysched VALUES (
    'PC1035', 0, 2000, .10);

INSERT INTO roysched VALUES (
    'PC1035', 2001, 4000, .12);

INSERT INTO roysched VALUES (
    'PC1035', 4001, 50000, .16);

INSERT INTO roysched VALUES (
    'BU2075', 0, 1000, .10);

INSERT INTO roysched VALUES (
    'BU2075', 1001, 5000, .12);

INSERT INTO roysched VALUES (
    'BU2075', 5001, 7000, .16);

INSERT INTO roysched VALUES (
    'BU2075', 7001, 50000, .18);

INSERT INTO roysched VALUES (
    'PS9999', 0, 50000, .10);

INSERT INTO roysched VALUES (
    'PS2091', 0, 1000, .10);

INSERT INTO roysched VALUES (
    'PS2091', 1001, 5000, .12);

INSERT INTO roysched VALUES (
    'PS2091', 5001, 50000, .14);

INSERT INTO roysched VALUES (
    'PS2106', 0, 2000, .10);

INSERT INTO roysched VALUES (
    'PS2106', 2001, 5000, .12);

INSERT INTO roysched VALUES (
    'PS2106', 5001, 50000, .14);

INSERT INTO roysched VALUES (
    'MC3021', 0, 1000, .10);

INSERT INTO roysched VALUES (
    'MC3021', 1001, 2000, .12);

INSERT INTO roysched VALUES (
    'MC3021', 2001, 6000, .14);

INSERT INTO roysched VALUES (
    'MC3021', 6001, 8000, .18);

INSERT INTO roysched VALUES (
    'MC3021', 8001, 50000, .20);

INSERT INTO roysched VALUES (
    'TC3218', 0, 2000, .10);

INSERT INTO roysched VALUES (
    'TC3218', 2001, 6000, .12);

INSERT INTO roysched VALUES (
    'TC3218', 6001, 8000, .16);

INSERT INTO roysched VALUES (
    'TC3218', 8001, 50000, .16);

INSERT INTO roysched VALUES (
    'PC8888', 0, 5000, .10);

INSERT INTO roysched VALUES (
    'PC8888', 5001, 50000, .12);

INSERT INTO roysched VALUES (
    'PS7777', 0, 5000, .10);

INSERT INTO roysched VALUES (
    'PS7777', 5001, 50000, .12);

INSERT INTO roysched VALUES (
    'PS3333', 0, 5000, .10);

INSERT INTO roysched VALUES (
    'PS3333', 5001, 50000, .12);

INSERT INTO roysched VALUES (
    'MC3026', 0, 1000, .10);

INSERT INTO roysched VALUES (
    'MC3026',1001, 2000, .12);

INSERT INTO roysched VALUES (
    'MC3026', 2001, 6000, .14);

INSERT INTO roysched VALUES (
    'MC3026', 6001, 8000, .18);

INSERT INTO roysched VALUES (
    'MC3026', 8001, 50000, .20);

INSERT INTO roysched VALUES (
    'BU1111', 0, 4000, .10);

INSERT INTO roysched VALUES (
    'BU1111', 4001, 8000, .12);

INSERT INTO roysched VALUES (
    'BU1111', 8001, 50000, .14);

INSERT INTO roysched VALUES (
    'MC2222', 0, 2000, .10);

INSERT INTO roysched VALUES (
    'MC2222', 2001, 4000, .12);

INSERT INTO roysched VALUES (
    'MC2222', 4001, 8000, .14);

INSERT INTO roysched VALUES (
    'MC2222', 8001, 12000, .16);

INSERT INTO roysched VALUES (
    'TC7777', 0, 5000, .10);

INSERT INTO roysched VALUES (
    'TC7777', 5001, 15000, .12);

INSERT INTO roysched VALUES (
    'TC4203', 0, 2000, .10);

INSERT INTO roysched VALUES (
    'TC4203', 2001, 8000, .12);

INSERT INTO roysched VALUES (
    'TC4203', 8001, 16000, .14);

INSERT INTO roysched VALUES (
    'BU7832', 0, 5000, .10);

INSERT INTO roysched VALUES (
    'BU7832', 5001, 50000, .12);

INSERT INTO roysched VALUES (
    'PS1372', 0, 50000, .10);


INSERT INTO titleauthors VALUES (
    '409-56-7008', 'BU1032', 1, .60);

INSERT INTO titleauthors VALUES (
    '486-29-1786', 'PS7777', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '486-29-1786', 'PC9999', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '712-45-1867', 'MC2222', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '172-32-1176', 'PS3333', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '213-46-8915', 'BU1032', 2, .40);

INSERT INTO titleauthors VALUES (
    '238-95-7766', 'PC1035', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '213-46-8915', 'BU2075', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '998-72-3567', 'PS2091', 1, .50);

INSERT INTO titleauthors VALUES (
    '899-46-2035', 'PS2091', 2, .50);

INSERT INTO titleauthors VALUES (
    '998-72-3567', 'PS2106', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '722-51-5454', 'MC3021', 1, .75);

INSERT INTO titleauthors VALUES (
    '899-46-2035', 'MC3021', 2, .25);

INSERT INTO titleauthors VALUES (
    '807-91-6654', 'TC3218', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '274-80-9391', 'BU7832', 1, 1.00);

INSERT INTO titleauthors VALUES (
    '427-17-2319', 'PC8888', 1, .50);

INSERT INTO titleauthors VALUES (
    '846-92-7186', 'PC8888', 2, .50);

INSERT INTO titleauthors VALUES (
    '756-30-7391', 'PS1372', 1, .75);

INSERT INTO titleauthors VALUES (
    '724-80-9391', 'PS1372', 2, .25);

INSERT INTO titleauthors VALUES (
    '724-80-9391', 'BU1111', 1, .60);

INSERT INTO titleauthors VALUES (
    '267-41-2394', 'BU1111', 2, .40);

INSERT INTO titleauthors VALUES (
    '672-71-3249', 'TC7777', 1, .40);

INSERT INTO titleauthors VALUES (
    '267-41-2394', 'TC7777', 2, .30);

INSERT INTO titleauthors VALUES (
    '472-27-2349', 'TC7777', 3, .30);

INSERT INTO titleauthors VALUES (
    '648-92-1872', 'TC4203', 1, 1.00);


INSERT INTO titles VALUES (
    'PC8888', 'Secrets of Silicon Valley',
    'popular_comp', '1389', '$20.00', '$8000.00', 4095, 'true',
    'Muckraking reporting on the world''s largest computer hardware and software manufacturers.',
    '06/12/1985');

INSERT INTO titles VALUES (
    'BU1032', 'The Busy Executive''s Database Guide',
    'business', '1389', '$19.99', '$5000.00', 4095, 'true',
    'An overview of available database systems with emphasis on common business applications.  Illustrated.',
    '06/12/1985');

INSERT INTO titles VALUES (
    'PS7777', 'Emotional Security: A New Algorithm',
    'psychology', '0736', '$7.99', '$4000.00', 3336, 'true',
    'Protecting yourself and your loved ones from undue emotional stress in the modern world.  Use of computer and nutritional aids emphasized.',
    '06/12/1985');

INSERT INTO titles VALUES (
    'PS3333', 'Prolonged Data Deprivation: Four Case Studies',
    'psychology', '0736', '$19.99', '$2000.00', 4072, 'true',
    'What happens when the data runs dry?  Searching evaluations of information-shortage effects.',
    '06/12/1985');

INSERT INTO titles VALUES (
    'BU1111', 'Cooking with Computers: Surreptitious Balance Sheets',
    'business', '1389', '$11.95', '$5000.00', 3876, 'true',
    'Helpful hints on how to use your electronic resources to the best advantage.', '06/09/1985');

INSERT INTO titles VALUES (
    'MC2222', 'Silicon Valley Gastronomic Treats',
    'mod_cook', '0877', '$19.99', '$0.00', 2032, 'true',
    'Favorite recipes for quick, easy, and elegant meals tried and tested by people who never have time to eat, let alone cook.',
    '06/09/1985');

INSERT INTO titles VALUES (
    'TC7777', 'Sushi, Anyone?',
    'trad_cook', '0877', '$14.99', '$8000.00', 4095, 'true',
    'Detailed instructions on improving your position in life by learning how to make authentic Japanese sushi in your spare time. 5-10% increase in number of friends per recipe reported from beta test. ',
    '06/12/1985');

INSERT INTO titles VALUES (
    'TC4203', 'Fifty Years in Buckingham Palace Kitchens',
    'trad_cook', '0877', '$11.95', '$4000.00', 15096, 'true',
    'More anecdotes from the Queen''s favorite cook describing life among English royalty.  Recipes, techniques, tender vignettes.',
    '06/12/1985');

INSERT INTO titles VALUES (
    'PC1035', 'But Is It User Friendly?',
    'popular_comp', '1389', '$22.95', '$7000.00', 8780, 'true',
    'A survey of software for the naive user, focusing on the ''friendliness'' of each.',
    '06/30/1985');

INSERT INTO titles VALUES (
    'BU2075', 'You Can Combat Computer Stress!',
    'business', '0736', '$2.99', '$10125.00', 18722, 'true',
    'The latest medical and psychological techniques for living with the electronic office.  Easy-to-understand explanations.',
    '06/30/1985');

INSERT INTO titles VALUES (
    'PS2091', 'Is Anger the Enemy?',
    'psychology', '0736', '$10.95', '$2275.00', 2045, 'true',
    'Carefully researched study of the effects of strong emotions on the body. Metabolic charts included.',
    '06/15/1985');

INSERT INTO titles VALUES (
    'PS2106', 'Life Without Fear',
    'psychology', '0736', '$7.00', '$6000.00', 111, 'true',
    'New exercise, meditation, and nutritional techniques that can reduce the shock of daily interactions. Popular audience.  Sample menus included,exercise video available separately.',
    '10/05/1985');

INSERT INTO titles VALUES (
    'MC3021', 'The Gourmet Microwave',
    'mod_cook', '0877', '$2.99', '$15000.00',22246, 'true',
    'Traditional French gourmet recipes adapted for modern microwave cooking.',
    '06/18/1985');

INSERT INTO titles VALUES (
    'TC3218',
    'Onions, Leeks, and Garlic: Cooking Secrets of the Mediterranean',
    'trad_cook', '0877', '$20.95', '$7000.00', 375, 'true',
    'Profusely illustrated in color, this makes a wonderful gift book for a cuisine-oriented friend.',
'10/21/1985');

INSERT INTO titles (title_id, title, pub_id, contract) VALUES (
    'MC3026', 'The Psychology of Computer Cooking', '0877', 'false');

INSERT INTO titles VALUES (
    'BU7832', 'Straight Talk About Computers',
    'business', '1389', '$19.99', '$5000.00', 4095, 'true',
    'Annotated analysis of what computers can do for you: a no-hype guide for the critical user.',
    '06/22/1985');

INSERT INTO titles VALUES (
    'PS1372',
    'Computer Phobic and Non-Phobic Individuals: Behavior Variations',
    'psychology', '0736', '$21.59', '$7000.00', 375, 'true',
    'A must for the specialist, this book examines the difference between those who hate and fear computers and those who think they are swell.',
'10/21/1985');

INSERT INTO titles (title_id, title, type, pub_id, contract, notes) VALUES (
    'PC9999', 'Net Etiquette', 'popular_comp', '1389', 'false',
    'A must-read for computer conferencing debutantes!');


INSERT INTO editors VALUES (
    '321-55-8906', 'DeLongue', 'Martinella', 'project',
    '415 843-2222', '3000 6th St.', 'Berkeley', 'CA', '94710');

INSERT INTO editors VALUES (
    '723-48-9010', 'Sparks', 'Manfred', 'copy',
    '303 721-3388', '15 Sail', 'Denver', 'CO', '80237');

INSERT INTO editors VALUES (
    '777-02-9831', 'Samuelson', 'Bernard', 'project',
    '415 843-6990', '27 Yosemite', 'Oakland', 'CA', '94609');

INSERT INTO editors VALUES (
    '777-66-9902', 'Almond', 'Alfred', 'copy',
    '312 699-4177', '1010 E. Devon', 'Chicago', 'IL', '60018');

INSERT INTO editors VALUES (
    '826-11-9034', 'Himmel', 'Eleanore', 'project',
    '617 423-0552', '97 Bleaker', 'Boston', 'MA', '02210');

INSERT INTO editors VALUES (
    '885-23-9140', 'Rutherford-Hayes', 'Hannah', 'project',
    '301 468-3909', '32 Rockbill Pike', 'Rockbill', 'MD', '20852');

INSERT INTO editors VALUES (
    '993-86-0420', 'McCann', 'Dennis', 'acquisition',
    '301 468-3909', '32 Rockbill Pike', 'Rockbill', 'MD', '20852');

INSERT INTO editors VALUES (
    '943-88-7920', 'Kaspchek', 'Christof', 'acquisition',
    '415 549-3909', '18 Severe Rd.', 'Berkeley', 'CA', '94710');

INSERT INTO editors VALUES (
    '234-88-9720', 'Hunter', 'Amanda', 'acquisition',
    '617 432-5586', '18 Dowdy Ln.', 'Boston', 'MA', '02210');


INSERT INTO titleditors VALUES (
    '826-11-9034', 'BU2075', 2);

INSERT INTO titleditors VALUES (
    '826-11-9034', 'PS2091', 2);

INSERT INTO titleditors VALUES (
    '826-11-9034', 'PS2106', 2);

INSERT INTO titleditors VALUES (
    '826-11-9034', 'PS3333', 2);

INSERT INTO titleditors VALUES (
    '826-11-9034', 'PS7777', 2);

INSERT INTO titleditors VALUES (
    '826-11-9034', 'PS1372', 2);

INSERT INTO titleditors VALUES (
    '885-23-9140', 'MC2222', 2);

INSERT INTO titleditors VALUES (
    '885-23-9140', 'MC3021', 2);

INSERT INTO titleditors VALUES (
    '885-23-9140', 'TC3281', 2);

INSERT INTO titleditors VALUES (
    '885-23-9140', 'TC4203', 2);

INSERT INTO titleditors VALUES (
    '885-23-9140', 'TC7777', 2);

INSERT INTO titleditors VALUES (
    '321-55-8906', 'BU1032', 2);

INSERT INTO titleditors VALUES (
    '321-55-8906', 'BU1111', 2);

INSERT INTO titleditors VALUES (
    '321-55-8906', 'BU7832', 2);

INSERT INTO titleditors VALUES (
    '321-55-8906', 'PC1035', 2);

INSERT INTO titleditors VALUES (
    '321-55-8906', 'PC88888', 2);

INSERT INTO titleditors VALUES (
    '321-55-8906', 'BU2075', 3);

INSERT INTO titleditors VALUES (
    '777-02-9831', 'PC1035', 3);

INSERT INTO titleditors VALUES (
    '777-02-9831', 'PC8888', 3);

INSERT INTO titleditors VALUES (
    '943-88-7920', 'BU1032', 1);

INSERT INTO titleditors VALUES (
    '943-88-7920', 'BU1111', 1);

INSERT INTO titleditors VALUES (
    '943-88-7920', 'BU2075', 1);

INSERT INTO titleditors VALUES (
    '943-88-7920', 'BU7832', 1);

INSERT INTO titleditors VALUES (
    '943-88-7920', 'PC1035', 1);

INSERT INTO titleditors VALUES (
    '943-88-7920', 'PC8888', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'PS1372', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'PS2091', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'PS2106', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'PS3333', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'PS7777', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'MC2222', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'MC3021', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'TC3218', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'TC4203', 1);

INSERT INTO titleditors VALUES (
    '993-86-0420', 'TC7777', 1);


INSERT INTO sales VALUES (
    1,'7066', 'QA7442.3', '09/13/1985');

INSERT INTO sales VALUES (
    2,'7067', 'D4482', '09/14/1985');

INSERT INTO sales VALUES (
    3,'7131', 'N914008', '09/14/1985');

INSERT INTO sales VALUES (
    4,'7131', 'N914014', '09/14/1985');

INSERT INTO sales VALUES (
    5,'8042', '423LL922', '09/14/1985');

INSERT INTO sales VALUES (
    6,'8042', '423LL930', '09/14/1985');

INSERT INTO sales VALUES (
    7, '6380', '722a', '09/13/1985');

INSERT INTO sales VALUES (
    8,'6380', '6871', '09/14/1985');

INSERT INTO sales VALUES (
    9,'8042','P723', '03/11/1988');

INSERT INTO sales VALUES (
    19,'7896','X999', '02/21/1988');

INSERT INTO sales VALUES (
    10,'7896','QQ2299', '10/28/1987');

INSERT INTO sales VALUES (
    11,'7896','TQ456', '12/12/1987');

INSERT INTO sales VALUES (
    12,'8042','QA879.1', '5/22/1987');

INSERT INTO sales VALUES (
    13,'7066','A2976', '5/24/1987');

INSERT INTO sales VALUES (
    14,'7131','P3087a', '5/29/1987');

INSERT INTO sales VALUES (
    15,'7067','P2121', '6/15/1987');


INSERT INTO salesdetails VALUES (
    1, 75, 75,'PS2091', '9/15/1985');

INSERT INTO salesdetails VALUES (
    2, 10, 10,'PS2091', '9/15/1985');

INSERT INTO salesdetails VALUES (
    3, 20, 720,'PS2091', '9/18/1985');

INSERT INTO salesdetails VALUES (
    4, 25, 20,'MC3021', '9/18/1985');

INSERT INTO salesdetails VALUES (
    5, 15, 15,'MC3021', '9/14/1985');

INSERT INTO salesdetails VALUES (
    6, 10, 3,'BU1032', '9/22/1985');

INSERT INTO salesdetails VALUES (
    7, 3, 3,'PS2091', '9/20/1985');

INSERT INTO salesdetails VALUES (
    8, 5, 5,'BU1032', '9/14/1985');

INSERT INTO salesdetails VALUES (
    9, 25, 5,'BU1111', '03/28/1988');

INSERT INTO salesdetails VALUES (
    19, 35, 35,'BU2075', '03/15/1988');

INSERT INTO salesdetails VALUES (
    10, 15, 15,'BU7832', '10/29/1987');

INSERT INTO salesdetails VALUES (
    11, 10, 10,'MC2222', '1/12/1988');

INSERT INTO salesdetails VALUES (
    12, 30, 30,'PC1035', '5/24/1987');

INSERT INTO salesdetails VALUES (
    13, 50, 50,'PC8888', '5/24/1987');

INSERT INTO salesdetails VALUES (
    14, 20, 20,'PS1372', '5/29/1987');

INSERT INTO salesdetails VALUES (
    14, 25, 25,'PS2106', '4/29/1987');

INSERT INTO salesdetails VALUES (
    14, 15, 10,'PS3333', '5/29/1987');

INSERT INTO salesdetails VALUES (
    14, 25, 25,'PS7777', '6/13/1987');

INSERT INTO salesdetails VALUES (
    15, 40, 40,'TC3218', '6/15/1987');

INSERT INTO salesdetails VALUES (
    15, 20, 20,'TC4203', '5/30/1987');

INSERT INTO salesdetails VALUES (
    15, 20, 10,'TC7777', '6/17/1987');


CREATE VIEW titleview AS
  SELECT title, au_ord, au_lname, price, ytd_sales, pub_id
    FROM authors, titles, titleauthors
    WHERE authors.au_id = titleauthors.au_id
    AND titles.title_id = titleauthors.title_id;

CREATE VIEW oaklanders AS
  SELECT au_fname, au_lname, title
    FROM authors, titles, titleauthors
    WHERE authors.au_id = titleauthors.au_id
    AND titles.title_id = titleauthors.title_id
    AND city = 'Oakland';

CREATE VIEW books AS
  SELECT titles.title_id, au_ord, au_lname, au_fname
    FROM authors, titles, titleauthors
    WHERE authors.au_id=titleauthors.au_id and
    titles.title_id = titleauthors.title_id;

CREATE VIEW royaltychecks AS
  SELECT au_lname, au_fname,
         SUM(price*ytd_sales*royalty*royaltyshare) AS Total_Income
    FROM authors, titles, titleauthors, roysched
    WHERE authors.au_id=titleauthors.au_id
    AND titles.title_id = titleauthors.title_id
    AND titles.title_id = roysched.title_id
    AND ytd_sales between lorange and hirange
    GROUP BY au_lname, au_fname;

-- currentinfo view (new!)

CREATE VIEW currentinfo AS
  SELECT pub_id AS pubnum, type, SUM(price * ytd_sales) AS income,
         AVG(price) AS avg_price, AVG(ytd_sales) AS avg_sales
    FROM titles
    GROUP BY pub_id, type;

CREATE VIEW hiprice AS
  SELECT *
    FROM titles
    WHERE price > '$15' AND advance > '$5000';

-- cities view (new!)

CREATE VIEW cities AS
  SELECT au_lname AS author, authors.city AS authorCity,
         pub_name AS pub, publishers.city AS pubCity
    FROM authors, publishers
    WHERE authors.city = publishers.city;

CREATE VIEW highaverage AS
  SELECT authors.au_id, titles.title_id, pub_name, price
    FROM authors, titleauthors, titles, publishers
    WHERE authors.au_id = titleauthors.au_id and
	titles.title_id = titleauthors.title_id and
	titles.pub_id = publishers.pub_id and
	price >	(SELECT avg(price) FROM titles);

CREATE VIEW highBandH AS
  SELECT *
    FROM highaverage
    WHERE pub_name = 'Binnet & Hardley';

CREATE VIEW number1 AS
  SELECT au_lname, phone
    FROM authors
    WHERE zip like '94%';

-- number2 view (new WHERE clause!)

CREATE VIEW number2 AS
  SELECT au_lname, phone
    FROM number1
    WHERE au_lname ~ '^[M-Z].*';

CREATE VIEW number3 AS
  SELECT au_lname, phone
    FROM number2
    WHERE au_lname = 'MacFeather';

-- accounts view (new!)

CREATE VIEW accounts AS
  SELECT title_id AS title, advance, (price * ytd_sales) AS gross_sales
    FROM titles
    WHERE price > '$15'
    AND advance > '$5000';

-- categories view (new!)

CREATE VIEW categories AS
  SELECT type AS category, avg(price) AS average_price
    FROM titles
    group by type;

